drop table BPEL_ACTIVITY_INST cascade constraints;
drop table BPEL_BASE_ACTIVITY_DEF cascade constraints;
drop table BPEL_FAULT_ cascade constraints;
drop table BPEL_REC cascade constraints;
drop table COPY_FULL_IMPL cascade constraints;
drop table CORR_DEF_ cascade constraints;
drop table CS_INIT_FULL_IMPL cascade constraints;
drop table ELSEIF_DEF_ cascade constraints;
drop table FRM_PRT_DEF_ cascade constraints;
drop table FROM_TO_FULL cascade constraints;
drop table NOVA_CS_INST_PROP cascade constraints;
drop table NOVA_NAMESPACE cascade constraints;
drop table ON_ALRM_DEF_ cascade constraints;
drop table ON_EVT_DEF_ cascade constraints;
drop table ON_MSG_DEF_ cascade constraints;
drop table PART_LNK_DEF_ cascade constraints;
drop table PLNK_UPDATE_FULL_IMPL cascade constraints;
drop table PROCESS_INST_STATE_UPDATE_ cascade constraints;
drop table SCOPE_STATE_UPDATE_ cascade constraints;
drop table SRC_FULL_IMPL cascade constraints;
drop table TGT_FULL_IMPL cascade constraints;
drop table TO_PRT_DEF_ cascade constraints;
drop table TR_COND_UPD_ cascade constraints;
drop table VAR_DEF_ cascade constraints;
drop table VAR_DEF_CS_ cascade constraints;
drop table VAR_UPDATE_FULL_IMPL cascade constraints;
drop table WAITING_FULL_IMPL cascade constraints;
drop table linkList cascade constraints;
drop table messageExchanges cascade constraints;
drop table properties cascade constraints;
drop sequence hibernate_sequence;
